==> apache-iotdb-0.12.1-source-release.zip: apache-iotdb-0.12.1/server/src/main/java/org/apache/iotdb/db/query/udf/core/transformer/UDFQueryRowTransformer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.db.query.udf.core.transformer;

import org.apache.iotdb.db.exception.query.QueryProcessException;
import org.apache.iotdb.db.query.udf.core.executor.UDTFExecutor;
import org.apache.iotdb.db.query.udf.core.reader.LayerRowReader;

import java.io.IOException;

public class UDFQueryRowTransformer extends UDFQueryTransformer {

  protected final LayerRowReader layerRowReader;

  public UDFQueryRowTransformer(LayerRowReader layerRowReader, UDTFExecutor executor) {
    super(executor);
    this.layerRowReader = layerRowReader;
  }

  @Override
  protected boolean executeUDFOnce() throws IOException, QueryProcessException {
    if (!layerRowReader.next()) {
      return false;
    }
    executor.execute(layerRowReader.currentRow());
    layerRowReader.readyForNext();
    return true;
  }
}

==> apache-iotdb-0.13.4-source-release.zip: apache-iotdb-0.13.4/server/src/main/java/org/apache/iotdb/db/query/udf/core/transformer/UDFQueryRowTransformer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.db.query.udf.core.transformer;

import org.apache.iotdb.db.exception.query.QueryProcessException;
import org.apache.iotdb.db.query.udf.core.executor.UDTFExecutor;
import org.apache.iotdb.db.query.udf.core.reader.LayerRowReader;

import java.io.IOException;

public class UDFQueryRowTransformer extends UDFQueryTransformer {

  protected final LayerRowReader layerRowReader;

  public UDFQueryRowTransformer(LayerRowReader layerRowReader, UDTFExecutor executor) {
    super(executor);
    this.layerRowReader = layerRowReader;
  }

  @Override
  protected boolean executeUDFOnce() throws IOException, QueryProcessException {
    if (!layerRowReader.next()) {
      return false;
    }
    if (layerRowReader.isCurrentNull()) {
      currentNull = true;
    }
    executor.execute(layerRowReader.currentRow(), currentNull);
    layerRowReader.readyForNext();
    return true;
  }
}
